unit u_plugin;

interface

uses Windows, Classes, SysUtils, u_ext_info, u_obimp_const, u_params;

type
  //Test plugin class
  TTestPlugin = class(TInterfacedObject, IExtensionPG)
  public
    EventsPG : IEventsPG;
    constructor Create(AEventsPG: IEventsPG);
    destructor  Destroy; override;

    {==== Interface functions ====}
    procedure TimerTick; stdcall;
    procedure NotifyTextMsg(const ExtPlugTextMsg: TExtPlugTextMsg); stdcall;
    procedure NotifyFileMsg(const ExtPlugFileMsg: TExtPlugFileMsg); stdcall;
  end;

implementation

{ TTestPlugin }
{***************************************************************}
constructor TTestPlugin.Create(AEventsPG: IEventsPG);
begin
  //save events interface, will be used for plugin callbacks
  EventsPG := AEventsPG;
end;

{***************************************************************}
destructor TTestPlugin.Destroy;
begin

  inherited;
end;

{***************************************************************}
procedure TTestPlugin.TimerTick;
begin
  //in this sample we didn't subscribe for timer ticks in extension params
end;

{***************************************************************}
procedure TTestPlugin.NotifyTextMsg(const ExtPlugTextMsg: TExtPlugTextMsg);
var ServerInfo: TExtServerInfo;
    sFileLog, sLogStr: string;
begin
  //get server info, there we can find logs folder path
  EventsPG.GetServerInfo(ServerInfo);

  sFileLog := IncludeTrailingPathDelimiter(ServerInfo.PathLogFiles) +
              'msglog_' + FormatDateTime('yyyy"-"mm"-"dd', Now) + '.txt';

  //compose log string
  sLogStr  := FormatDateTime('hh":"nn":"ss', Now) + ' ' + ExtPlugTextMsg.AccSender + ' -> ' + ExtPlugTextMsg.AccRcver;

  //if msg was sent by transport
  if (ExtPlugTextMsg.TranspOwnerAcc <> '') then
    sLogStr := sLogStr + ' # ' + ExtPlugTextMsg.TranspOwnerAcc + ' @ ' + ExtPlugTextMsg.TranspUUIDHex;

  //add line break and add msg text
  sLogStr := sLogStr + #13#10 +
             Trim(ExtPlugTextMsg.MsgText);

  //write log to file
  LogToFile(sFileLog, sLogStr);
end;

{***************************************************************}
procedure TTestPlugin.NotifyFileMsg(const ExtPlugFileMsg: TExtPlugFileMsg);
var ServerInfo: TExtServerInfo;
    sFileLog, sLogStr: string;
begin
  //get server info, there we can find logs folder path
  EventsPG.GetServerInfo(ServerInfo);

  sFileLog := IncludeTrailingPathDelimiter(ServerInfo.PathLogFiles) +
              'msglog_' + FormatDateTime('yyyy"-"mm"-"dd', Now) + '.txt';

  //compose log string
  sLogStr  := FormatDateTime('hh":"nn":"ss', Now) + ' ' + ExtPlugFileMsg.AccSender + ' -> ' + ExtPlugFileMsg.AccRcver;

  //add line break and add msg text
  sLogStr := sLogStr + #13#10 +
             'Files count: ' + IntToStr(ExtPlugFileMsg.FilesCount) + #13#10 +
             'Files size: ' + IntToStr(ExtPlugFileMsg.FilesSize);

  if (ExtPlugFileMsg.FilesCount > 1) then
    sLogStr := sLogStr + #13#10 +
               'File name: ' + ExtPlugFileMsg.FileName + ' and other ' + IntToStr(ExtPlugFileMsg.FilesCount-1) + ' files ...'
  else
    sLogStr := sLogStr + #13#10 +
               'File name: ' + ExtPlugFileMsg.FileName;

  sLogStr := sLogStr + #13#10 +
             'Sender IP: ' + ExtPlugFileMsg.SenderIP;

  //write log to file
  LogToFile(sFileLog, sLogStr);
end;



end.
